==> syncfusion_flutter_pdf-18.1.42-beta.tar.gz: lib/src/pdf/implementation/graphics/brushes/pdf_solid_brush.dart <==
part of pdf;

/// Represents a brush that fills any object with a solid color.
class PdfSolidBrush implements PdfBrush {
  //Constructor
  /// Initializes a new instance of the [PdfSolidBrush] class.
  PdfSolidBrush(PdfColor color) {
    this.color = color == null ? PdfColor(0, 0, 0) : color;
  }

  //Fields
  final PdfColorSpace _colorSpace = PdfColorSpace.rgb;

  /// Indicates the color of the [PdfSolidBrush].
  PdfColor color;

  @override
  bool operator ==(Object other) {
    return other is PdfSolidBrush ? color == other.color ? true : false : false;
  }

  @override
  int get hashCode => color.hashCode;

  @override
  bool _monitorChanges(
      PdfBrush brush,
      _PdfStreamWriter streamWriter,
      Function getResources,
      bool saveChanges,
      PdfColorSpace currentColorSpace) {
    ArgumentError.checkNotNull(getResources);
    ArgumentError.checkNotNull(streamWriter);
    bool diff = false;
    if (brush == null) {
      diff = true;
      streamWriter._setColorAndSpace(color, currentColorSpace, false);
    } else if (brush != this) {
      final PdfSolidBrush solidBrush = brush as PdfSolidBrush;
      if (solidBrush != null) {
        if (solidBrush.color != color ||
            solidBrush._colorSpace != currentColorSpace) {
          diff = true;
          streamWriter._setColorAndSpace(color, currentColorSpace, false);
        } else if (solidBrush._colorSpace == currentColorSpace &&
            currentColorSpace == PdfColorSpace.rgb) {
          diff = true;
          streamWriter._setColorAndSpace(color, currentColorSpace, false);
        }
      } else {
        brush._resetChanges(streamWriter);
        streamWriter._setColorAndSpace(color, currentColorSpace, false);
        diff = true;
      }
    }
    return diff;
  }

  @override
  void _resetChanges(_PdfStreamWriter streamWriter) {
    streamWriter._setColorAndSpace(PdfColor(0, 0, 0), PdfColorSpace.rgb, false);
  }
}

==> syncfusion_flutter_pdf-18.4.46-beta.tar.gz: lib/src/pdf/implementation/graphics/brushes/pdf_solid_brush.dart <==
part of pdf;

/// Represents a brush that fills any object with a solid color.
class PdfSolidBrush implements PdfBrush {
  //Constructor
  /// Initializes a new instance of the [PdfSolidBrush] class.
  PdfSolidBrush(PdfColor color) {
    this.color = color ?? PdfColor(0, 0, 0);
  }

  //Fields
  final PdfColorSpace _colorSpace = PdfColorSpace.rgb;

  /// Indicates the color of the [PdfSolidBrush].
  PdfColor color;

  @override
  bool operator ==(Object other) {
    return other is PdfSolidBrush
        ? color == other.color
            ? true
            : false
        : false;
  }

  @override
  int get hashCode => color.hashCode;

  @override
  bool _monitorChanges(
      PdfBrush brush,
      _PdfStreamWriter streamWriter,
      Function getResources,
      bool saveChanges,
      PdfColorSpace currentColorSpace) {
    ArgumentError.checkNotNull(getResources);
    ArgumentError.checkNotNull(streamWriter);
    bool diff = false;
    if (brush == null) {
      diff = true;
      streamWriter._setColorAndSpace(color, currentColorSpace, false);
    } else if (brush != this) {
      final PdfSolidBrush solidBrush = brush as PdfSolidBrush;
      if (solidBrush != null) {
        if (solidBrush.color != color ||
            solidBrush._colorSpace != currentColorSpace) {
          diff = true;
          streamWriter._setColorAndSpace(color, currentColorSpace, false);
        } else if (solidBrush._colorSpace == currentColorSpace &&
            currentColorSpace == PdfColorSpace.rgb) {
          diff = true;
          streamWriter._setColorAndSpace(color, currentColorSpace, false);
        }
      } else {
        brush._resetChanges(streamWriter);
        streamWriter._setColorAndSpace(color, currentColorSpace, false);
        diff = true;
      }
    }
    return diff;
  }

  @override
  void _resetChanges(_PdfStreamWriter streamWriter) {
    streamWriter._setColorAndSpace(PdfColor(0, 0, 0), PdfColorSpace.rgb, false);
  }
}
